@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: DialogFactory.h,v 1.2 2004/05/08 05:56:46 vkurland Exp $
+  $Id: DialogFactory.h,v 1.2.4.1 2005/10/25 06:11:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,6 +27,7 @@
 
 namespace libfwbuilder {
     class FWObject;
+    class FWException;
 };
 
 class DialogFactory {
@@ -34,7 +35,9 @@ class DialogFactory {
  public:
 
     static QWidget *createDialog(QWidget *parent,const QString &objType);
-    static QWidget *createFWDialog(QWidget *parent,libfwbuilder::FWObject *o);
-    static QWidget *createOSDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    static QWidget *createFWDialog(QWidget *parent,libfwbuilder::FWObject *o)
+        throw(libfwbuilder::FWException);
+    static QWidget *createOSDialog(QWidget *parent,libfwbuilder::FWObject *o)
+        throw(libfwbuilder::FWException);
     
 };
