@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp,v 1.154 2005/04/24 06:51:01 vkurland Exp $
+  $Id: FWWindow.cpp,v 1.155.4.2 2005/09/04 21:54:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -344,6 +344,7 @@ void FWWindow::fileProp()
     if (rcs!=NULL)
     {
         filePropDialog fpd(this,rcs);
+	fpd.setPrinter(printer);
         fpd.exec();
     }
 }
@@ -368,6 +369,7 @@ void FWWindow::fileNew()
 
         addToRCSAction->setEnabled( !rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
         fileDiscardAction->setEnabled( rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
+        fileCommitAction->setEnabled( rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
         fileSaveAction->setEnabled( !rcs->isRO() && !rcs->isTemp() );
 
         setupAutoSave();
@@ -482,6 +484,7 @@ void FWWindow::fileSaveAs()
 
         addToRCSAction->setEnabled( !rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
         fileDiscardAction->setEnabled( rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
+        fileCommitAction->setEnabled( rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
         fileSaveAction->setEnabled( !rcs->isRO() && !rcs->isTemp() );
     }
 }
@@ -495,6 +498,32 @@ void FWWindow::fileExit()
     }
 }
 
+void FWWindow::fileCommit()
+{
+    // Steps:
+    // 1.save the file
+    // 2.checkin (checkin() returns false when user hits Cancel)
+    // 3. close file
+    // 4. reopen it
+    
+    QString fname = rcs->getFileName();
+    save();
+    if (!checkin(true))  return;
+    fileClose();
+    try
+    {
+        RCS *rcs = new RCS(fname);
+        if (rcs==NULL) return;
+        rcs->co();
+        load(this,rcs);
+    } catch (FWException &ex)
+    {
+        load(this);
+        return;
+    }
+    showFirewalls();
+}
+
 /*
  * discard changes done to the file and check out clean copy of the
  * head revision from RCS
@@ -573,6 +602,7 @@ void FWWindow::fileAddToRCS()
 
     addToRCSAction->setEnabled( !rcs->isInRCS() && !rcs->isRO());
     fileDiscardAction->setEnabled( rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
+    fileCommitAction->setEnabled( rcs->isInRCS() && !rcs->isRO() && !rcs->isTemp());
 }
 
 bool FWWindow::editingLibrary()
@@ -659,6 +689,7 @@ void FWWindow::load(QWidget *dialogs_parent)
         fileSaveAction->setEnabled( false );
         addToRCSAction->setEnabled( false );
         fileDiscardAction->setEnabled( false );
+        fileCommitAction->setEnabled( false );
     
         if (fwbdebug) qDebug("FWWindow::load(): done");
 
@@ -920,6 +951,7 @@ void FWWindow::load(QWidget *dialogs_parent,RCS *_rcs)
         fileSaveAction->setEnabled( !rcs->isRO() && !rcs->isTemp());
         addToRCSAction->setEnabled( !rcs->isInRCS() && !rcs->isRO());
         fileDiscardAction->setEnabled( rcs->isInRCS() && !rcs->isRO());
+        fileCommitAction->setEnabled( rcs->isInRCS() && !rcs->isRO());
 
     } catch(FWException &ex)
     {
@@ -1437,7 +1469,7 @@ void FWWindow::openFirewall( int idx )
     {
         FWObject *fw=firewalls[idx];
         visibleFirewall = fw;
-        firewallName->setText( fw->getName().c_str() );
+        firewallName->setText(QString::fromUtf8(fw->getName().c_str()));
         reopenFirewall();
         om->openObject(fw);
     } else
