@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHPIX.cpp,v 1.11.4.2 2005/09/12 06:12:14 vkurland Exp $
+  $Id: SSHPIX.cpp,v 1.11.4.3 2006/04/12 07:34:47 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -51,7 +51,7 @@ SSHPIX::SSHPIX(const QString &_h,
                const QStringList &args,
                const QString &_p,
                const QString &_ep,
-               const QStringList &_in) : SSHSession(_h,args,_p,_ep,_in)
+               const std::list<std::string> &_in) : SSHSession(_h,args,_p,_ep,_in)
 {
     normal_prompt="> $";
     fwb_prompt="--**--**--";
