@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHPIX.h,v 1.4 2004/11/14 01:32:27 vkurland Exp $
+  $Id: SSHPIX.h,v 1.4.4.1 2006/04/12 07:34:47 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -59,7 +59,7 @@ public:
            const QStringList &args,
            const QString &pwd,
            const QString &epwd,
-           const QStringList &in);
+           const std::list<std::string> &in);
     virtual ~SSHPIX();
 
     virtual void stateMachine();
