@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.cpp,v 1.14.4.6 2006/03/26 17:36:27 vkurland Exp $
+  $Id: SSHSession.cpp,v 1.14.4.9 2006/04/13 07:08:48 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -39,6 +39,7 @@
 #include <qapplication.h>
 #include <qeventloop.h>
 #include <qcstring.h>
+#include <qtextcodec.h>
 
 #include <iostream>
 
@@ -60,7 +61,7 @@ SSHSession::SSHSession(const QString &_h,
                        const QStringList &_args,
                        const QString &_p,
                        const QString &_ep,
-                       const QStringList &_in)
+                       const list<string> &_in)
 {
     host = _h;
     args = _args;
@@ -113,6 +114,8 @@ void SSHSession::startSession()
     connect(proc,SIGNAL(readyReadStderr()), this,  SLOT(readFromStderr() ) );
     connect(proc,SIGNAL(processExited()),   this,  SLOT(processExited() ) );
 
+    QTextCodec::setCodecForCStrings(QTextCodec::codecForName("latin1"));
+
     for (QStringList::const_iterator i=args.begin(); i!=args.end(); ++i)
     {
         proc->addArgument( *i );
@@ -247,17 +250,32 @@ void SSHSession::sendLine()
     int n=0;
     while (input.size()!=0 && n<10)
     {
-        QString s = input.front();
+        string s = input.front();
         s = s + "\n";
         if (fwbdebug)
-            qDebug("SSHSession::sendLine : %d lines to go -- %s",input.size(),s.ascii());
+            qDebug("SSHSession::sendLine : %d lines to go -- %s",input.size(),s.c_str());
         input.pop_front();
-        QCString csc = s.utf8();
-        if (fwbdebug)
-            qDebug("SSHSession::sendLine : cs='%s'",(const char*)(csc));
 
         stdoutBuffer="";
-        proc->writeToStdin(csc); // send even if s is empty
+
+/* it is important that we use writeToStdin(QByteArray &) rather than
+ * writeToStdin(QString &) because the latter performs implicit
+ * conversion into local locale assuming the string is in Unicode. The
+ * string in our case is actually in whatever encoding the firewall
+ * script is written to the local filesystem, which may or may not be
+ * UTF-8 but is definitely not Unicode. The conversion not only breaks
+ * comments that were entered in UTF-8, it makes QProcess miscalculate
+ * number of characters in comment lines using UTF-8 which in turns
+ * breaks the script even worse because it glues consequitive lines
+ * together. Apparently this has been fixed in latest versions of QT
+ * 3.x but this is still broken in QT 3.1 which is shipping with
+ * RedHat 9 and some other still popular distributions. Since we need
+ * to support old QT 3.x, the code must work around this problem.
+ */
+        QByteArray buf;
+        buf.duplicate( s.c_str(), s.length() );
+        proc->writeToStdin(buf);
+
         n++;
     }
     emit updateProgressBar_sign(input.size(),false);
