@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.h,v 1.9.4.3 2005/09/08 06:05:57 vkurland Exp $
+  $Id: SSHSession.h,v 1.9.4.4 2006/04/12 07:34:47 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,6 +37,8 @@
 #include <qobject.h>
 
 #include <fstream>
+#include <string>
+#include <list>
 
 class QTimer;
 class instConf;
@@ -55,7 +57,8 @@ class SSHSession : public QObject {
     QString     scp;
     QString     cmd;
     QStringList args;
-    QStringList input;
+
+    std::list<std::string> input;
 
     bool       closeStdin;
     bool       logged_in;
@@ -146,7 +149,7 @@ public:
 	       const QStringList &args,
 	       const QString &pwd,
 	       const QString &epwd,
-	       const QStringList &in);
+	       const std::list<std::string> &in);
     virtual ~SSHSession();
 
     virtual void stateMachine();
