@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.h,v 1.2 2004/09/21 15:46:48 vkurland Exp $
+  $Id: SSHUnx.h,v 1.2.4.1 2006/04/12 07:34:47 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -46,7 +46,7 @@ public:
            const QStringList &args,
            const QString &pwd,
            const QString &epwd,
-           const QStringList &in);
+           const std::list<std::string> &in);
     virtual ~SSHUnx();
 
     virtual void stateMachine();
