@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: debugDialog.cpp,v 1.7 2005/05/29 01:13:35 vkurland Exp $
+  $Id: debugDialog.cpp,v 1.7.4.1 2005/12/15 07:25:18 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -82,6 +82,8 @@ debugDialog::debugDialog(QWidget *parent) : debugDialog_q(parent)
                  .arg( libfwbuilder::Constants::getLibraryVersion().c_str() ) );
     debugText->append( QString("  Built with QT %1").arg(QT_VERSION_STR) );
     debugText->append( QString("  Using QT %1").arg( qVersion() ) );
+    debugText->append( QString("  Built with libxml2 %1").arg(LIBXML_DOTTED_VERSION) );
+    debugText->append( QString("  Using libxml2 %1").arg(xmlParserVersion) );
     debugText->append( "\n" );
 
 
