@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: execDialog.h,v 1.2 2004/06/05 17:01:02 vkurland Exp $
+  $Id: execDialog.h,v 1.3 2005/04/17 21:58:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,7 +42,7 @@ class execDialog : public execDialog_q
     int      res;
     
 public:
-    execDialog(QWidget *parent,const QStringList &args);
+    execDialog(QWidget *parent,const QStringList &args, const QString &closeButtonText="");
 
     int run();
 
