@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.65.4.5 2006/03/26 17:36:27 vkurland Exp $
+  $Id: instDialog.cpp,v 1.65.4.6 2006/04/12 07:34:47 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -48,6 +48,7 @@
 #include <qfile.h>
 #include <qmessagebox.h>
 #include <qspinbox.h>
+#include <qtextcodec.h>
 
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -488,7 +489,7 @@ void instDialog::selected(const QString &title)
                                args,
                                cnf->pwd,
                                cnf->epwd,
-                               "") );
+                               list<string>()) );
         } else
         {
 /*
@@ -569,7 +570,7 @@ QString instDialog::getActivationCmd()
 void instDialog::initiateCopy(const QString &file)
 {
     QStringList args;
-    QStringList allConfig;
+    list<string> allConfig;
 
     if (fwbdebug)
         qDebug("instDialog::initiateCopy for the file %s",file.ascii());
@@ -579,6 +580,8 @@ void instDialog::initiateCopy(const QString &file)
 
     QString ff = cnf->wdir+"/"+file;
 
+    QTextCodec::setCodecForCStrings(QTextCodec::codecForName("latin1"));
+    
     std::ifstream   *config_file;
 
     config_file = new ifstream(ff.latin1());
@@ -597,12 +600,13 @@ void instDialog::initiateCopy(const QString &file)
     while ( !config_file->eof() )
     {
         getline( *config_file, s0);
-        QString s = QString::fromUtf8(s0.c_str());
-        s.stripWhiteSpace();
+//        QString s = QString::fromUtf8(s0.c_str());
+//        QString s = s0.c_str();
+//        s.stripWhiteSpace();
 
-        if (fwbdebug) qDebug("instDialog::initiateCopy s='%s'",s.ascii());
+        if (fwbdebug) qDebug("instDialog::initiateCopy s='%s'",s0.c_str());
 
-        allConfig.push_back(s);
+        allConfig.push_back(s0);
     }
     config_file->close();
     delete config_file;
@@ -672,6 +676,8 @@ void instDialog::initiateCopy(const QString &file)
 
     phase=1;
 
+    QTextCodec::setCodecForCStrings(QTextCodec::codecForName("latin1"));
+    
     SSHSession *s= new SSHUnx(cnf->fwobj->getName().c_str(),
                               args,
                               cnf->pwd,
@@ -787,7 +793,7 @@ void instDialog::continueRun()
                                args,
                                cnf->pwd,
                                "",
-                               "") );
+                               list<string>()) );
         }
 
     }
