@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: main.cpp,v 1.89.4.4 2006/03/26 17:36:27 vkurland Exp $
+  $Id: main.cpp,v 1.89.4.5 2006/04/13 07:08:48 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -501,31 +501,11 @@ int main( int argc, char ** argv )
                         endOfStream = true;
                     } else
                     {
-/* This is a workaround for the problem that exists with utf-8 encoded data
- * passed to stdin of a QProcess (and vice versa, see
- * http://lists.trolltech.com/qt-interest/2004-10/thread00024-0.html
- */
-                        char tbuf[BUFFSIZE];
-                        char *tptr1 = ibuf;
-                        char *tptr2 = tbuf;
-                        int no = n;
-                        int nr = 0;
-                        while (no)
-                        {
-                            if (*tptr1 != '\0')
-                            {
-                                *tptr2++ = *tptr1;
-                                nr++;
-                            }
-                            tptr1++;
-                            no--;
-                        }
-
-                        int r=writen(mfd,tbuf,nr);
-                        if (fwbdebug) qDebug("Wrote %d bytes to mfd",r);
+                        int r=writen(mfd,ibuf,n);
 #ifdef DEBUG_INSTALLER
-                        write(debug_file,tbuf,nr);
+                        write(debug_file,ibuf,n);
 #endif
+                        if (fwbdebug) qDebug("Wrote %d bytes to mfd",r);
                     }
                 }
                 if (FD_ISSET(mfd, &rfds))
