@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp,v 1.12.4.2 2005/09/13 04:55:41 vkurland Exp $
+  $Id: platforms.cpp,v 1.12.4.3 2005/10/25 06:11:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -132,7 +132,7 @@ QMap<QString,QString> getVersionsForPlatform(const QString &platform)
     {
         if (platform=="pix" || platform=="fwsm") 
         {
-            QString lst=Resources::platform_res[platform]->getResourceStr(
+            QString lst=Resources::platform_res[platform.ascii()]->getResourceStr(
                 "/FWBuilderResources/Target/versions").c_str();
 
             QStringList ll=QStringList::split(',', lst);
