@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipf.cpp,v 1.19 2005/05/29 03:13:02 vkurland Exp $
+  $Id: ipf.cpp,v 1.19.4.1 2006/03/19 06:08:18 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -437,8 +437,10 @@ int main(int argc, char * const *argv)
                << user_name << "\n#\n#\n";
 
         fw_file << MANIFEST_MARKER << "* " << fw_file_name << endl;
-        fw_file << MANIFEST_MARKER << "  " << ipf_file_name << endl;
-        fw_file << MANIFEST_MARKER << "  " << nat_file_name << endl;
+      	if (have_ipf) 
+            fw_file << MANIFEST_MARKER << "  " << ipf_file_name << endl;
+      	if (have_nat) 
+            fw_file << MANIFEST_MARKER << "  " << nat_file_name << endl;
         fw_file << "#" << endl;
         fw_file << "#" << endl;
 
@@ -492,6 +494,7 @@ int main(int argc, char * const *argv)
         fw_file << "# End of prolog script" << endl;
         fw_file << "#" << endl;
 
+        unlink(ipf_file_name.c_str());
       	if (have_ipf) 
         {
             ofstream ipf_file;
@@ -518,6 +521,7 @@ int main(int argc, char * const *argv)
             }
 	}
 
+        unlink(nat_file_name.c_str());
 	if (have_nat) 
         {
             ofstream nat_file;
