@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.cpp,v 1.11 2004/12/29 07:56:23 vkurland Exp $
+  $Id: NATCompiler_ipt.cpp,v 1.11.4.1 2005/11/02 06:16:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -616,6 +616,7 @@ bool NATCompiler_ipt::fillTranslatedSrv::processNext()
 
 bool NATCompiler_ipt::addVirtualAddress::processNext()
 {
+    FWOptions* options=compiler->fw->getOptionsObject();
     NATRule *rule=getNext(); if (rule==NULL) return false;
 
     tmp_queue.push_back(rule);
@@ -629,7 +630,8 @@ bool NATCompiler_ipt::addVirtualAddress::processNext()
         else
             a=compiler->getFirstODst(rule);
 
-        if ( ! a->isAny() && ! compiler->complexMatch(a,compiler->fw) )
+        if ( ! a->isAny() && ! compiler->complexMatch(a,compiler->fw) && 
+             options->getBool("manage_virtual_addr") )
         {
             if (AddressRange::cast(a)!=NULL)
             {
