@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.cpp,v 1.27 2005/05/04 16:39:10 vkurland Exp $
+  $Id: OSConfigurator_linux24.cpp,v 1.27.4.1 2006/03/27 04:41:46 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -574,10 +574,10 @@ void OSConfigurator_linux24::generateCodeForProtocolHandlers(bool have_nat)
         string version=fw->getStr("version");
         if (have_nat)
         {
-            output << "MODULES=`(cd $MODULE_DIR; ls *_conntrack_* *_nat_* | sed -n -e 's/\\.ko$//p' -e 's/\\.o$//p' -e 's/\\.ko\\.gz$//p' -e 's/\\.o\\.gz$//p')`"
+            output << "MODULES=`(cd $MODULE_DIR; ls *_conntrack* *_nat_* | sed -n -e 's/\\.ko$//p' -e 's/\\.o$//p' -e 's/\\.ko\\.gz$//p' -e 's/\\.o\\.gz$//p')`"
                    << endl;
         } else {
-            output << "MODULES=`(cd $MODULE_DIR; ls *_conntrack_* | sed -n -e 's/\\.ko$//p' -e 's/\\.o$//p' -e 's/\\.ko\\.gz$//p' -e 's/\\.o\\.gz$//p')`"
+            output << "MODULES=`(cd $MODULE_DIR; ls *_conntrack* | sed -n -e 's/\\.ko$//p' -e 's/\\.o$//p' -e 's/\\.ko\\.gz$//p' -e 's/\\.o\\.gz$//p')`"
                    << endl;
         }
 
