@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_PrintRule.cpp,v 1.11 2005/05/28 21:16:18 vkurland Exp $
+  $Id: PolicyCompiler_PrintRule.cpp,v 1.11.4.1 2006/03/19 06:08:18 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1011,7 +1011,11 @@ string PolicyCompiler_ipt::PrintRule::PolicyRuleToString(PolicyRule *rule)
     if ((!ruleopt->getBool("stateless") && rule->getStr("stored_action")=="Accept") ||
          rule->getBool("force_state_check") )
     {
-	command_line << " -m state --state NEW ";
+        /*
+         * But not, when the line already contains a state matching
+         */
+        if (command_line.str().find("-m state --state", 0) == string::npos)
+            command_line << " -m state --state NEW ";
     }
 
     command_line << _printTimeInterval(rule);
